@@ -16,8 +16,10 @@
 
 import yaml
 
+from oslo_utils import strutils
+
 from tackerclient.common import exceptions
-from tackerclient.common import utils
+from tackerclient.i18n import _
 from tackerclient.tacker import v1_0 as tackerV10
 from tackerclient.tacker.v1_0.nfvo import vim_utils
 
@@ -47,25 +49,25 @@ class CreateVIM(tackerV10.CreateCommand):
         parser.add_argument(
             '--config-file',
             required=True,
-            help='Specify VIM specific config parameters in a file')
+            help=_('YAML file with VIM configuration parameters'))
         parser.add_argument(
             'name', metavar='NAME',
-            help='Set a name for the VIM')
+            help=_('Set a name for the VIM'))
         parser.add_argument(
             '--description',
-            help='Set a description for the VIM')
+            help=_('Set a description for the VIM'))
         parser.add_argument(
             '--is-default',
             action='store_true',
             default=False,
-            help='Set as default VIM')
+            help=_('Set as default VIM'))
 
     def args2body(self, parsed_args):
         body = {self.resource: {}}
         if parsed_args.config_file:
             with open(parsed_args.config_file) as f:
                 vim_config = f.read()
-                config_param = yaml.load(vim_config)
+                config_param = yaml.load(vim_config, Loader=yaml.SafeLoader)
         vim_obj = body[self.resource]
         try:
             auth_url = config_param.pop('auth_url')
@@ -73,7 +75,7 @@ class CreateVIM(tackerV10.CreateCommand):
             raise exceptions.TackerClientException(message='Auth URL must be '
                                                            'specified',
                                                    status_code=404)
-        vim_obj['auth_url'] = utils.validate_url(auth_url).geturl()
+        vim_obj['auth_url'] = vim_utils.validate_auth_url(auth_url).geturl()
         vim_obj['type'] = config_param.pop('type', 'openstack')
         vim_utils.args2body_vim(config_param, vim_obj)
         tackerV10.update_dict(parsed_args, body[self.resource],
@@ -90,12 +92,19 @@ class UpdateVIM(tackerV10.UpdateCommand):
     def add_known_arguments(self, parser):
         parser.add_argument(
             '--config-file',
-            help='Specify VIM specific config parameters in a file')
+            required=True,
+            help=_('YAML file with VIM configuration parameters'))
+        parser.add_argument(
+            '--name',
+            help=_('New name for the VIM'))
+        parser.add_argument(
+            '--description',
+            help=_('New description for the VIM'))
         parser.add_argument(
             '--is-default',
-            action='store_true',
-            default=False,
-            help='Set as default VIM')
+            type=strutils.bool_from_string,
+            metavar='{True,False}',
+            help=_('Indicate whether the VIM is used as default'))
 
     def args2body(self, parsed_args):
         body = {self.resource: {}}
@@ -111,10 +120,11 @@ class UpdateVIM(tackerV10.UpdateCommand):
         vim_obj = body[self.resource]
         vim_utils.args2body_vim(config_param, vim_obj)
         tackerV10.update_dict(parsed_args, body[self.resource],
-                              ['tenant_id', 'is_default'])
+                              ['tenant_id', 'name', 'description',
+                               'is_default'])
         return body
 
 
 class DeleteVIM(tackerV10.DeleteCommand):
-    """Delete a given VIM."""
+    """Delete given VIM(s)."""
     resource = _VIM
