@@ -30,8 +30,8 @@ class ListVNF(tackerV10.ListCommand):
     """List VNF that belong to a given tenant."""
 
     resource = _VNF
-    list_columns = ['id', 'name', 'description', 'mgmt_url', 'status',
-                    'vim_id', 'placement_attr', 'error_reason']
+    list_columns = ['id', 'name', 'mgmt_url', 'status',
+                    'vim_id', 'vnfd_id']
 
 
 class ShowVNF(tackerV10.ShowCommand):
@@ -60,6 +60,9 @@ class CreateVNF(tackerV10.CreateCommand):
         vnfd_group.add_argument(
             '--vnfd-name',
             help=_('VNFD Name to use as template to create VNF'))
+        vnfd_group.add_argument(
+            '--vnfd-template',
+            help=_("VNFD file to create VNF"))
         vim_group = parser.add_mutually_exclusive_group()
         vim_group.add_argument(
             '--vim-id',
@@ -75,7 +78,7 @@ class CreateVNF(tackerV10.CreateCommand):
             help=_('YAML file with VNF configuration'))
         parser.add_argument(
             '--config',
-            help=_('Specify config yaml data'))
+            help=_('Specify config yaml data (DEPRECATED)'))
         parser.add_argument(
             '--param-file',
             help=_('Specify parameter yaml file'))
@@ -90,14 +93,16 @@ class CreateVNF(tackerV10.CreateCommand):
                 config_yaml = f.read()
             config = yaml.load(
                 config_yaml, Loader=yaml.SafeLoader)
+
         if parsed_args.config:
+            # TODO(sridhar_ram): Only file based input supported starting
+            #       Ocata, remove all direct inputs in Pike
+            utils.deprecate_warning(what="Direct config YAML input", as_of="O",
+                                    remove_in=1)
             config = parsed_args.config
-            if isinstance(config, str):
+            if isinstance(config, str) or isinstance(config, unicode):
                 config_str = parsed_args.config.decode('unicode_escape')
                 config = yaml.load(config_str, Loader=yaml.SafeLoader)
-                utils.deprecate_warning(what='yaml as string', as_of='N',
-                                        in_favor_of='yaml as dictionary')
-
         if config:
             args['attributes']['config'] = config
         if parsed_args.vim_region_name:
@@ -118,6 +123,12 @@ class CreateVNF(tackerV10.CreateCommand):
                                                               parsed_args.
                                                               vnfd_name)
                 parsed_args.vnfd_id = _id
+        elif parsed_args.vnfd_template:
+            with open(parsed_args.vnfd_template) as f:
+                template = f.read()
+            args['vnfd_template'] = yaml.load(
+                template, Loader=yaml.SafeLoader)
+
         if parsed_args.param_file:
             with open(parsed_args.param_file) as f:
                 param_yaml = f.read()
@@ -152,11 +163,9 @@ class UpdateVNF(tackerV10.UpdateCommand):
             config = yaml.load(config_yaml, Loader=yaml.SafeLoader)
         if parsed_args.config:
             config = parsed_args.config
-            if isinstance(parsed_args.config, str):
+            if isinstance(config, str) or isinstance(config, unicode):
                 config_str = parsed_args.config.decode('unicode_escape')
                 config = yaml.load(config_str, Loader=yaml.SafeLoader)
-                utils.deprecate_warning(what='yaml as string', as_of='N',
-                                        in_favor_of='yaml as dictionary')
         if config:
             body[self.resource]['attributes'] = {'config': config}
         tackerV10.update_dict(parsed_args, body[self.resource], ['tenant_id'])
